@@ -8,7 +8,7 @@ use Carp;
 use vars qw(@ISA $VERSION);
 
 @ISA = qw(Inline::C);
-$VERSION = '0.28';
+$VERSION = '0.29';
 my $TYPEMAP_KIND = $Inline::CPP::grammar::TYPEMAP_KIND;
 
 #============================================================================
@@ -42,7 +42,7 @@ sub validate {
 		     };
     $o->{ILSM}{AUTO_INCLUDE} ||= <<END;
 #ifndef bool
-#include <iostream>
+#include <%iostream%>
 #endif
 extern "C" {
 #include "EXTERN.h"
@@ -52,9 +52,9 @@ extern "C" {
 }
 #ifdef bool
 #undef bool
-#include <iostream>
+#include <%iostream%>
 #endif
-using namespace std;
+
 END
     $o->{ILSM}{PRESERVE_ELLIPSIS} = 0 
       unless defined $o->{ILSM}{PRESERVE_ELLIPSIS};
@@ -88,10 +88,10 @@ END
 	push @propagate, $key, $value;
     }
 
-#    # Replace %iostream% with the correct iostream library
-#    my $iostream = "iostream";
+    # Replace %iostream% with the correct iostream library
+    my $iostream = "iostream";
 #    $iostream .= ".h" unless $o->{ILSM}{STD_IOSTREAM};
-#    $o->{ILSM}{AUTO_INCLUDE} =~ s|%iostream%|$iostream|g;
+    $o->{ILSM}{AUTO_INCLUDE} =~ s|%iostream%|$iostream|g;
 
     # Forward all unknown requests up to Inline::C
     $o->SUPER::validate(@propagate) if @propagate;
@@ -478,8 +478,12 @@ sub typeconv {
     my $dir = shift;
     my $preproc = shift;
     my $tkind = $o->{ILSM}{typeconv}{type_kind}{$type};
-    my $ret =
-      eval qq{qq{$o->{ILSM}{typeconv}{$dir}{$tkind}}};
+    my $ret;
+    {
+        no strict;
+        $ret = 
+            eval qq{qq{$o->{ILSM}{typeconv}{$dir}{$tkind}}};
+    }
     chomp $ret;
     $ret =~ s/\n/\\\n/g if $preproc;
     return $ret;
